// Last modified on February 8th, 2010 -- F. Gelis

#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <unistd.h>


// We need to include the definitions of the stuff defined in
// laguerre.c and dglap.c

#include "laguerre.h"
#include "dglap.h"


// Definition of the initial PDFs

// PDFs at Q0^2=1GeV^2, from Bartels,Golec-Biernat,Kowalsky (Fit
// 2). This appears in the context of a "saturation inspired" fit of
// HERA F2.

double qns0(double x){
  return 0.0; // no quarks
}

double qs0(double x){
  return 0.0; // no quarks
}

double g0(double x){
  return 13.71*pow(x,0.41)*pow(1.0-x,5.6);
}


// The main program

int main(void){
  double Nf=3.0;             // number of flavors
  int N=100;                 // maximum Laguerre order
  double q2i=1.0;            // initial value of Q^2
  double q2f=1.0e18;          // final value of Q^2
  double q2,x;
  tab_Pij *tt_pij;
  tab_dist *dist0;
  evol_pair pair;
  tab_evol *tt_evol;
  tab_alpha *tt_alpha;
  grid_dist *dist;
  value_dist val;

  //tt_pij=create_Lag_Pij_table_DLA(Nf,N);  // Use this for DLA DGLAP
  tt_pij=create_Lag_Pij_table(Nf,N);
  dist0=Lag_dist(N,qns0,qs0,g0);
  dist0->q2=q2i; 
  
  set_LO();
  set_NO_QUARKS();
  set_NO_RUNNING();
  compute_GLUON_DERIVATIVE();


  pair=DGLAP_evol(dist0,q2f,4000,tt_pij);

  tt_evol  = pair.pdf;
  tt_alpha = pair.alpha;

  dist = PDF_grid_calc(2000,1.0e-8,tt_evol);

  //PDF_grid_write(dist,"BGBK");
  //dist=PDF_grid_read("BGBK");

  q2=1.0e2;

  for (x=1e-4;x<1;x*=1.05){
    val=PDF_interpolated(x,q2,dist);
    fprintf(stdout,"%.10e %.10e %.10e %.10e %.10e\n",x,val.qns,val.qs,val.g,val.dg);
  }
  fprintf(stdout,"\n");
 
  exit(0);
}
